@@ -816,131 +816,132 @@ structure(list(NA_real_, NA_real_, k3 = c(0.166666666666667,
 "k6", "k7", "k8", "k9", "k10", "k11", "k12", "k13", "k14", "k15"
 ))
 .Random.seed <-
-c(403L, 10L, 1807124276L, -1274121062L, -1065207067L, 2041701503L, 
-1552383494L, 600566160L, -175492045L, 944774097L, 1163776384L, 
--1283851170L, 583039913L, -1185283493L, 617780842L, 1753185036L, 
-1861954895L, -2081982971L, 2068610236L, -816890478L, -751618419L, 
--1966420793L, 2087004590L, -1371188216L, 1385105419L, 992386281L, 
-1516403640L, 1642734694L, 1137476865L, 1123795859L, 783369282L, 
--1157358604L, -722823689L, 1613179373L, -2137150844L, -1187656534L, 
--655173099L, 478594735L, -1462426442L, 541815520L, -1307537885L, 
-763416897L, 1498524720L, -36137394L, 1395483321L, -1866524981L, 
--861835398L, 1360057980L, -1965010241L, -1765805163L, 1649800108L, 
--1889109630L, -896696483L, -25357737L, 55548222L, 370833784L, 
--827649445L, -1564133959L, -90093560L, 1972533942L, -100617743L, 
-589965347L, 225896562L, -635602236L, -2113598329L, 1216921693L, 
-1611597396L, -1981782918L, 1302777797L, -397602529L, -1656110938L, 
-1369989680L, 863328467L, 2142377713L, -988105184L, 763994302L, 
--926145335L, -1329934725L, -1677296566L, 143312044L, 1547903919L, 
--2110257307L, 1468177692L, -1031035534L, 1353346541L, -2111233497L, 
-496431694L, -295160152L, -18101077L, 1579855305L, 712319448L, 
--2647930L, -943422111L, -1708558093L, 1958438754L, 1956065748L, 
-2057802967L, -1756588339L, -563044764L, -1017619382L, -554878539L, 
-1440580879L, -1819938282L, -977933120L, -667030909L, -1417111903L, 
-802756752L, 101905262L, -989315815L, 401583531L, -2088866918L, 
-917848924L, -765164961L, 2108164661L, -1910099508L, -209286878L, 
-1312377725L, -1987712905L, 1738096030L, -855608232L, 116683195L, 
--704084135L, 436954344L, 1366953238L, 55258769L, 1333846851L, 
-370531922L, 522678500L, -763804889L, -796862595L, -1091093900L, 
-1755907162L, -1189512027L, -78797121L, 1294417222L, -630668336L, 
-1353698803L, -1032107759L, -401836736L, -439405282L, 1577046505L, 
-1339761435L, 1413459242L, -1392007604L, -404143601L, 1367881029L, 
-722212604L, -1762988718L, -1915043123L, 403905159L, -438010514L, 
-2016229192L, -1525673141L, -852247895L, -1996501000L, 1796480806L, 
--174137279L, 716984787L, -19874942L, -113242188L, -591526089L, 
-1067441709L, -667349180L, -1302131606L, -2052163883L, 1399316591L, 
--1034133130L, 1799514784L, 130766691L, -2126676991L, 262317936L, 
-1237708558L, 1276709241L, 867646731L, 1875756602L, 1940593980L, 
-1097273983L, -1853908523L, -1357293588L, -1686116030L, -605391203L, 
--1927716073L, 1378792062L, -1976188360L, -937061093L, 1568170617L, 
--1590714680L, -582854922L, -401211599L, 315225955L, -508859086L, 
--1106080124L, 68840135L, -2012575331L, -721937132L, 2005562298L, 
-768939525L, 1562302431L, 90189414L, 703265264L, -1733503213L, 
--230680399L, 57756512L, -719406850L, 1246685321L, 837056443L, 
-1852436874L, 933716076L, -1445330449L, -790619611L, 1982803676L, 
--834861902L, 788858797L, -644072601L, -1985341298L, 1362089320L, 
-582944107L, -44833015L, 400562584L, 1582858438L, 3777057L, -981587277L, 
--104998878L, 231105044L, 1590650519L, 1964767373L, 856825252L, 
-229531530L, -3339275L, -1651731568L, -1234368260L, 1793802644L, 
-300389186L, -318285312L, 437015612L, 197270096L, 1843082402L, 
--586827960L, -1916019188L, -646091044L, -1814835118L, -1614118784L, 
-763636564L, -363310104L, -915438854L, -78057648L, -1547014100L, 
-861167988L, -558546286L, -1747332512L, -1559964532L, -84335264L, 
-1430022370L, -1116852056L, 125602508L, -420039172L, 1206853554L, 
--893712400L, -1910315580L, 78895448L, 1020163450L, 1153226160L, 
--1329579588L, 763824724L, 40512962L, 1187486496L, 1638206396L, 
-1248126032L, 1866633186L, -1286728856L, -653244596L, -229922052L, 
--711984398L, 1171050752L, 1077965940L, 1144834568L, -706356806L, 
--1764070960L, -1301509140L, 822376340L, -835904302L, -719697824L, 
-992366924L, 952727328L, -1714431358L, 1720412648L, 450655212L, 
-1113132604L, 2039851634L, -1288425616L, -326581980L, 391933496L, 
-1595678106L, -1237842480L, -1399217732L, -470150508L, -1376295294L, 
-1111536064L, 911241020L, -853154160L, 929837858L, 464586248L, 
-1208121100L, 1399150492L, -1497837550L, 480797568L, 2029588244L, 
--1132336856L, -1953828806L, -592132144L, -1159968148L, -1928340428L, 
--894139246L, -889918112L, -2010672820L, 114784736L, 1588539298L, 
--946974808L, -1752161140L, 1019487164L, -441239438L, -1442913296L, 
-627007556L, -1733131176L, -278831046L, 1311268976L, -1690127812L, 
-1573354260L, 1930862274L, 911666912L, -1973054340L, 972775632L, 
--618523742L, -796851672L, 2008401164L, 1795886012L, 1734788402L, 
-1518820544L, 979734068L, 1617360584L, 2054641338L, 1429332112L, 
--1625371924L, -1575208364L, -470696302L, -2132165856L, -1704490036L, 
--1708462880L, -329372990L, -1999163352L, 1012255660L, -112194884L, 
-1706161650L, -1858451920L, 1410191268L, 1463850424L, -1400864934L, 
-449325200L, 1403808636L, 1496654612L, -379096766L, -982760704L, 
--921993284L, -629398704L, -1433914078L, 1433980488L, -368453620L, 
--309288868L, 1636428242L, -631862784L, -1462501036L, 804320488L, 
-530803962L, -738183472L, -1424155348L, 871205108L, 821233042L, 
-1087191392L, 1834752012L, 1716907744L, -2022061470L, 668393128L, 
-78001740L, 196729724L, 1034704178L, 724328048L, -462877884L, 
-1908380632L, 2043096954L, 1272975920L, -1895412804L, 1244701268L, 
-243420226L, 495122592L, 1776267964L, -1430741552L, -944212126L, 
--1825885464L, 1431508172L, -563884548L, 492665330L, -1965582720L, 
-54740468L, -684268920L, -1013090502L, 1658560336L, -35840916L, 
-1862102420L, -1846174638L, -114955808L, -1587350324L, 1220034720L, 
-626305410L, 907098344L, -365382932L, 2114630972L, 436927602L, 
-242443376L, -2042778588L, -1741553608L, -1467458790L, 1913314512L, 
-334236476L, -1502677100L, 991514498L, -1287248448L, 1249915452L, 
-353298832L, -160749022L, -524153592L, -1612850548L, -1079916772L, 
-641704082L, -1421860480L, 1860010516L, 2005779240L, -1565391302L, 
--1133868592L, -1191684756L, -2063244364L, -63255534L, 135836128L, 
-1261028300L, -954351392L, -1936041950L, -762909400L, 2087548428L, 
--2135297220L, -1029176334L, 795688688L, 258964036L, -936157608L, 
-215069498L, -224968208L, 110845628L, 225578260L, -787476707L, 
-1183595978L, 459134696L, -1534346799L, -273241149L, -527670076L, 
-1765423986L, -816789945L, -910805487L, 644511638L, -645256460L, 
-1380252805L, -250715697L, -1595607864L, -1093446298L, 424691603L, 
--1824331531L, 1277313234L, 725462816L, 1026920201L, -583755717L, 
-757747084L, -646560742L, -284518257L, -1615106087L, -2074931090L, 
--764932L, -840466067L, -306160873L, 1765952224L, 1716467902L, 
--1743169909L, 2097966349L, 1298792762L, 854208888L, -1429798111L, 
-237163475L, -168854796L, 1233507202L, -1253350889L, -1514975007L, 
-148831782L, -1400711388L, 739440597L, 1967910783L, -1582253544L, 
-2015156534L, 1426778051L, -645380603L, 1249322402L, 1651124624L, 
-521064761L, -1468455445L, -1063835940L, 2113557258L, 1714650623L, 
-1221051465L, -1509034530L, 1341228428L, -366816931L, -1747572377L, 
-2095413904L, 632714414L, -982366885L, -310908611L, 795136938L, 
--1216306104L, 748047473L, 30509539L, -601987868L, -284213230L, 
--1015450649L, 1307843505L, -1533086218L, 1933105172L, 84784933L, 
-424497199L, -299304472L, -2093900090L, 2094489459L, -789596203L, 
-439947186L, -521135744L, 1261650281L, -502479397L, 1084898604L, 
-1612334906L, -87950865L, -1018798983L, 1603464974L, 1438788316L, 
-219474253L, -88824649L, -1019773376L, -2137379042L, 585131499L, 
-732846445L, 1412773850L, 856453528L, -1196253183L, 869749171L, 
-1839024340L, 1903889890L, 62806135L, -1063907903L, -1332549818L, 
-34894468L, -1090675659L, 967679007L, -1232340104L, 1729020502L, 
--826028317L, 57682085L, 874215746L, -485081296L, 1716087641L, 
--744570677L, 545984828L, -1541186198L, 671594399L, -1912298967L, 
--494170946L, -791194196L, -51139843L, -1422236089L, -1724746448L, 
-312739406L, 1376466555L, 144160221L, -1535245302L, 461313320L, 
-537246609L, -1024549501L, 1469586052L, -839735118L, 1436743687L, 
-310891601L, 1186284502L, -1075078476L, -250434875L, -1191875569L, 
-1142967432L, 1048821158L, -1678543533L, -32436555L, 974775314L, 
-1754568160L, -1435371447L, 677404283L, -1134147764L, 1891734234L, 
-83957455L, 1026422425L, -1712051538L, 136402876L, -911568851L, 
-1835257815L, 1420142112L, 1962297214L, -262264501L, 705170253L, 
-531249530L, 1389665208L, -401235615L, 1977773331L, -495717068L, 
--323379390L, 1077067607L, -727576927L, 545806166L)
+c(403L, 32L, -1313655383L, -1044067085L, -1138018404L, 1673106914L, 
+1545747826L, 179429618L, -1651492925L, -1220951369L, 899262132L, 
+1841495577L, 1898112065L, 1166942114L, -1936696613L, -166271962L, 
+-1842379283L, 137168445L, 1360831745L, -1253313093L, -1598421477L, 
+1991796589L, 177795349L, 1724057911L, -619568320L, -1460691944L, 
+-1665418936L, -1046652562L, -1722394511L, -1561106020L, 233013348L, 
+1772410475L, 1957262124L, -1822719415L, 384567504L, -1188568200L, 
+1405486159L, 1187340733L, -2111393578L, -1261125866L, 1254991368L, 
+1659471545L, -1794157396L, -238629496L, 1088761454L, -511212392L, 
+1859118556L, -1490323672L, 1610974289L, 678561108L, -32526229L, 
+174396179L, -1394445086L, 703102616L, 407146868L, -2078672036L, 
+1256457033L, 294791545L, 1051403850L, 1396252213L, 920609836L, 
+-1238097601L, -270571078L, -885015652L, -1886896974L, -1111869269L, 
+-1897073303L, 2060178631L, 309211348L, 737382455L, 381880273L, 
+406504622L, 322561947L, 418156606L, 826888637L, -945429503L, 
+-209952944L, -441320544L, -1560528309L, -660161893L, 299996096L, 
+-1703900038L, 938431591L, -558192135L, -1019549103L, -1672329068L, 
+1201372622L, 1450438703L, 402448730L, -2000724175L, -1014260896L, 
+-1931428323L, -1308716858L, -248208943L, 835223455L, -1724511354L, 
+-1257580837L, 2136338864L, -1141822223L, -1894714451L, -1132888420L, 
+1595688073L, -217493913L, -2115909373L, 1571707517L, 1591925212L, 
+-1067871747L, -1018294891L, -896583058L, -391838768L, 302272755L, 
+-390347203L, 1462647316L, 799891782L, -1790159337L, 748023879L, 
+159575618L, -1309899144L, -195330703L, 329722657L, -565598334L, 
+-1722461179L, 270049812L, -710479260L, -337812810L, -1853869426L, 
+-762990952L, 48262590L, -1197634419L, -1303096116L, 1803599878L, 
+954858014L, 726730240L, 1570516623L, -330294068L, 1577108601L, 
+1319064190L, 638519887L, 1246160781L, -2027933481L, 731496724L, 
+1730406235L, -1407870010L, 809914237L, -136033714L, 857559469L, 
+-149520119L, -1777854207L, -843282854L, -871960071L, 659362552L, 
+718069151L, -611561423L, 338816492L, -1445995921L, -81531105L, 
+-1073642119L, 1521151928L, -223675932L, 125033276L, 1667917047L, 
+-402635858L, 482872989L, 1242891154L, 1942193217L, 79352565L, 
+1313524708L, 195978209L, 69741174L, -1312155576L, 765872807L, 
+-1060639975L, -533469453L, 2130499504L, -1494163607L, -218197082L, 
+-2102439294L, 626561515L, 241193531L, 222122984L, 849687351L, 
+-1329956590L, -149014256L, -2015303586L, -1438748405L, 1737049072L, 
+-132179160L, 1679630794L, -568284434L, 742353165L, 55375826L, 
+-1078017852L, 421695022L, 1327889240L, -1503614507L, 32234643L, 
+1254483715L, -1329473632L, -575796063L, 358537051L, -855695797L, 
+824227879L, -1729821191L, 676503235L, -1409706927L, -1220816300L, 
+559566648L, -489043489L, -1323338543L, -1856725329L, 217616266L, 
+-850464816L, 662035922L, -1971545537L, -638500449L, 1128223955L, 
+1841396459L, -619297234L, -1106369729L, 741406458L, -228964598L, 
+-135692550L, -415150124L, -1092491375L, -1106316513L, -2041493043L, 
+-743324990L, -640276354L, 893158712L, 79881785L, 259691653L, 
+-518499215L, 91553569L, 1419048091L, 1379593679L, 490643031L, 
+137364535L, -187738073L, -1633295995L, 1778622138L, -938968491L, 
+2072700433L, 1587518503L, -247754371L, -885986378L, -1957271467L, 
+-2054585046L, -144313342L, 127386173L, 690602433L, -2066938320L, 
+192407988L, -1227453816L, -1835739574L, -1446328530L, -446065297L, 
+-1324295481L, 1808142298L, -1077131090L, 713312401L, 176894867L, 
+-290246018L, -1919888873L, -323107480L, -779130222L, 75866497L, 
+315953862L, 1972384197L, -503475227L, -1054460128L, 1749915135L, 
+1195708349L, 702689467L, -811378646L, 1603266005L, -858288831L, 
+-1217571003L, -1784903766L, 1355414720L, 591259547L, 742618990L, 
+769384466L, -1429600743L, -165588617L, 380149244L, -1214198694L, 
+-558405688L, 505292793L, 1951467840L, -815008921L, 791717367L, 
+890280568L, 159585921L, -509101366L, 929706108L, -1022558099L, 
+-1227474374L, -789023910L, -1927620187L, -1924537019L, -177451935L, 
+-591206913L, -164748335L, -843739150L, -1569822239L, -118748707L, 
+649845678L, -823882596L, 1092164920L, 727633320L, -1672155090L, 
+830299776L, -798845332L, -1409655101L, -384003944L, 2113070897L, 
+-1055740573L, -1116224766L, -149017416L, 914515614L, -1601120797L, 
+-1175077960L, 635043640L, -1535600078L, 1478021893L, 1727886288L, 
+1671251412L, 1625661593L, -1269522504L, -117450764L, 1320982462L, 
+1055543110L, -2063554869L, -555638435L, -922472653L, 233721215L, 
+-1029322078L, 799206482L, 799446426L, 782704024L, 1193356916L, 
+292113243L, 1617180488L, 2030814080L, -1114780640L, 1532617049L, 
+1231805611L, -1067442892L, -1356925211L, 1532362880L, 132521241L, 
+-82812776L, -552336929L, 1495651968L, 2039728414L, 2126844121L, 
+-985328359L, -1994947529L, -1038514567L, 1436843471L, 2114856360L, 
+1635515001L, 976586155L, -71203483L, 891545339L, -638692642L, 
+1430613133L, -378644142L, 290469753L, 1180768959L, -1685873244L, 
+353720976L, 1443297821L, -471222006L, 1134630668L, 321211584L, 
+-1701219567L, 57954525L, -975674228L, 1042023524L, -209671509L, 
+1740538067L, -471220693L, 1170938953L, 296635809L, 1486193016L, 
+580866282L, 1932048863L, 228446328L, 1815508540L, -1879275707L, 
+-2140354011L, 143924871L, -1986488283L, 589904000L, 1903750703L, 
+-415443172L, 1859307430L, -1469176564L, 497566432L, -721627866L, 
+414959067L, 2119608405L, -2056242432L, 1748790347L, -1836524280L, 
+-604319628L, 647673962L, -2055352872L, 1743204552L, 724809221L, 
+629724965L, 261337954L, -336291101L, 73908369L, -2006206083L, 
+-1832558056L, 807246340L, -48863616L, -182367148L, 1212537756L, 
+1232486002L, -486827130L, 982651407L, -394299582L, 210724779L, 
+1305713339L, 1721807473L, -1635674346L, 1284179303L, 689688268L, 
+-1473515637L, -1103667165L, 1232126541L, -174355958L, -163254679L, 
+897435999L, -1678310327L, -1504585109L, 1539585450L, 990684448L, 
+-1498933867L, -1023184718L, -35646167L, 331792546L, 730166067L, 
+1805991271L, 1662342745L, 2058042350L, 1274100405L, -656110916L, 
+1939758265L, -690892225L, -1703892180L, 743388093L, -176795619L, 
+842862460L, -52841045L, 1464291695L, 993756365L, -1369750890L, 
+-801310429L, -675370673L, -1538352917L, -808325592L, 1466383484L, 
+1826784035L, 829129643L, 1279779620L, 1077232139L, -740684867L, 
+-844945669L, -703246794L, -474551677L, -148324544L, -1556251256L, 
+-783700436L, -574946419L, 1225485881L, 1961374901L, -1118832472L, 
+125980600L, -259295769L, 730077669L, -1283473195L, 728194711L, 
+-387044539L, 1689519239L, 250946503L, 190861505L, 1770075403L, 
+-793651039L, 400586806L, 975298806L, 641814340L, 1127569593L, 
+1478152005L, -66220139L, 613576818L, 563083520L, -1759960774L, 
+1507455734L, 289932207L, -428167323L, 1242795809L, -1137320636L, 
+517604505L, 180344843L, 2127807329L, -1718531053L, -1038847805L, 
+310395024L, -1640526618L, 1264206939L, 393730669L, -1956611761L, 
+634560140L, -67253725L, 1155306924L, 1240896408L, -637557255L, 
+94923525L, -978754831L, 1275289986L, 291846590L, 1915055832L, 
+1163523235L, 822266910L, -481178691L, 1937010816L, 239405847L, 
+597445786L, 1758199875L, 1446620402L, 175169290L, 609673531L, 
+1884633281L, 938877300L, -641451098L, -1875308359L, -2110940784L, 
+1009133294L, -801629269L, 1306023320L, -496748005L, -1691788265L, 
+1961102437L, -1503120899L, 469906541L, 1806337495L, -384871920L, 
+163994338L, 1414772416L, 1077327799L, -969426492L, -914600642L, 
+-706091035L, -1472608170L, 1933734468L, -382933522L, 1509038384L, 
+-2145769488L, 1013192113L, -998078197L, -56609482L, -951495796L, 
+-270028884L, -2135722482L, -557376975L, -1349815574L, -841130365L, 
+-1833685961L, -1135178962L, 1805416481L, -1707325387L, -835233650L, 
+-1775980440L, 1568787060L, 1590960471L, 365667936L, -1792969509L, 
+644149446L, 1258804967L, -539491416L, 551146069L, 117520920L, 
+706791561L, -623008986L, 392369787L, -1598319152L, 918051753L, 
+1457969483L, -51299690L, -296048864L, -1867524345L, 1994962544L, 
+666722704L, 397334122L, 417341718L, 937322299L, 1863174697L, 
+-1698178314L, -1543228816L, 631929173L, -772382884L, -1672121366L, 
+-638439291L, 1025633280L, 1136328884L, 1516095699L, 1095939602L, 
+693378375L, 579558920L, 905772869L, -774725317L, 1805573117L, 
+1236612744L, -2005094588L, -1711550111L, -391735297L, 651021245L, 
+829215356L, 264655358L, -2006715365L, 2107674005L, 1774128903L
+)
 .txtline <-
 function(txt, width, space="", ind="") {
   paste(
@@ -950,26 +951,26 @@ function(txt, width, space="", ind="") {
 }
 .WrdPrepRep <-
 function( wrd, main="Bericht" ){
-
+  
   # only internal user out from GetNewWrd()
   # creates new word instance and prepares document for report
-
+  
   # constants
   # wdPageBreak <- 7
-  # wdSeekCurrentPageHeader <- 9	### Kopfzeile
+  # wdSeekCurrentPageHeader <- 9  ### Kopfzeile
   # wdSeekCurrentPageFooter <- 10	### Fusszeile
   # wdSeekMainDocument <- 0
   # wdPageFitBestFit <- 2
   # wdFieldEmpty <- -1
-
+  
   # Show DocumentMap
   wrd[["ActiveWindow"]][["DocumentMap"]] <- TRUE
   wrdWind <- wrd[["ActiveWindow"]][["ActivePane"]][["View"]][["Zoom"]]
   wrdWind[["PageFit"]] <- wdConst$wdPageFitBestFit
-
+  
   wrd[["Selection"]]$TypeParagraph()
   wrd[["Selection"]]$TypeParagraph()
-
+  
   wrd[["Selection"]]$WholeStory()
   # 15.1.2012 auskommentiert: WrdSetFont(wrd=wrd)
   
@@ -977,26 +978,26 @@ function( wrd, main="Bericht" ){
   #wrd[["ActiveDocument"]][["Styles"]]$Item("berschrift 2")[["Font"]][["Name"]] <- "Consolas"
   #wrd[["ActiveDocument"]][["Styles"]]$Item("berschrift 2")[["Font"]][["Size"]] <- 10
   #wrd[["ActiveDocument"]][["Styles"]]$Item("berschrift 2")[["Font"]][["Bold"]] <- TRUE
-
+  
   #wrd[["ActiveDocument"]][["Styles"]]$Item("berschrift 2")[["ParagraphFormat"]]["Borders"]]$Item(wdBorderTop)[["LineStyle"]] <- wdConst$wdLineStyleSingle
   
   WrdCaption( main, wrd=wrd)
   wrd[["Selection"]]$TypeText(gettextf("%s/%s\n",format(Sys.time(), "%d.%m.%Y"), Sys.getenv("username")))
   wrd[["Selection"]]$InsertBreak( wdConst$wdPageBreak)
-
+  
   # Inhaltsverzeichnis einfgen ***************
   wrd[["ActiveDocument"]][["TablesOfContents"]]$Add( wrd[["Selection"]][["Range"]] )
   # Original VB-Code:
   # With ActiveDocument
-        # .TablesOfContents.Add Range:=Selection.Range, RightAlignPageNumbers:= _
-            # True, UseHeadingStyles:=True, UpperHeadingLevel:=1, _
-            # LowerHeadingLevel:=2, IncludePageNumbers:=True, AddedStyles:="", _
-            # UseHyperlinks:=True, HidePageNumbersInWeb:=True, UseOutlineLevels:= _
-            # True
-        # .TablesOfContents(1).TabLeader = wdTabLeaderDots
-        # .TablesOfContents.Format = wdIndexIndent
-    # End With
-
+  # .TablesOfContents.Add Range:=Selection.Range, RightAlignPageNumbers:= _
+  # True, UseHeadingStyles:=True, UpperHeadingLevel:=1, _
+  # LowerHeadingLevel:=2, IncludePageNumbers:=True, AddedStyles:="", _
+  # UseHyperlinks:=True, HidePageNumbersInWeb:=True, UseOutlineLevels:= _
+  # True
+  # .TablesOfContents(1).TabLeader = wdTabLeaderDots
+  # .TablesOfContents.Format = wdIndexIndent
+  # End With
+  
   # Fusszeile	***************
   wrdView <- wrd[["ActiveWindow"]][["ActivePane"]][["View"]]
   wrdView[["SeekView"]] <- wdConst$wdSeekCurrentPageFooter
@@ -1004,7 +1005,7 @@ function( wrd, main="Bericht" ){
   wrd[["Selection"]][["Fields"]]$Add( wrd[["Selection"]][["Range"]], wdConst$wdFieldEmpty, "PAGE" )
   wrd[["Selection"]]$TypeText("\n\n")
   wrdView[["SeekView"]] <- wdConst$wdSeekMainDocument
-
+  
   wrd[["Selection"]]$InsertBreak( wdConst$wdPageBreak)
-
+  
 }
